@@ -1,19 +1,16 @@
 import abc
-import simplejson as json
-from enum import Enum
 from functools import cached_property
 
+import simplejson as json
+
+from worker import constants
+from worker.data.enums import EventType
 from worker.data.json_encoder import JsonEncoder
-from worker.framework import constants
-
-
-class EventType(Enum):
-    SCHEDULER = "scheduler"
-    WITS_STREAM = "wits_stream"
 
 
 class Event(abc.ABC):
     """An event class that holds the events of a single asset_id."""
+
     def __init__(self, event_type: EventType):
         self.event_type: EventType = event_type
 
@@ -41,7 +38,7 @@ class Event(abc.ABC):
         If there is no lambda app following your app then this should be false,
         because this process is intracting with the API which slows the process down.
         """
-        is_posting: bool = constants.get('global.post-to-message-producer', False)
+        is_posting: bool = constants.get("global.post-to-message-producer", False)
         return is_posting
 
     @abc.abstractmethod
@@ -53,4 +50,4 @@ class Event(abc.ABC):
             return
 
         payload = self.build_message_producer_payload()
-        api.post(path='/v1/message_producer', data=json.dumps(payload, cls=JsonEncoder, ignore_nan=True))
+        api.post(path="/v1/message_producer", data=json.dumps(payload, cls=JsonEncoder, ignore_nan=True))
